@@ -214,7 +214,7 @@ class Dxr_Publisher:
                 await_topic = topic.topic
         if await_topic is None:
             return None
-        print('await_publish: ' + await_topic)
+        # print('await_publish: ' + await_topic)
         cond = get_cond(await_topic)
         if cond is None:
             return None
