@@ -196,6 +196,31 @@ class cloud_platform_c(msg):
         self.msg = self.msg_class()  # 消息体
 
 
+# 云台控制返回值
+class cloud_platform_c_response(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":{
+            "error_code":0,
+            "error_msg":"",
+            "result":1
+        }
+    }
+    """
+    topic = "/cloud_platform_c_response"
+
+    class msg_class(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.error_code = ""  # int型
+            self.error_msg = ""  # string型
+            self.result = ""  # int型
+
+    def __init__(self):
+        super().__init__()
+        self.msg = self.msg_class()  # 消息体
+        
 # 启动或关闭录包
 class data_record(msg):
     """
@@ -1238,7 +1263,7 @@ class audio_voice_control(msg):
         }
     }
     """
-    topic = "/audio/voice/control"
+    topic = "/audio_voice_control"
     
     class msg_class(NestedClass):
         def __init__(self):
@@ -1263,7 +1288,7 @@ class audio_voice_control_response(msg):
         }
     }
     """
-    topic = "/audio/voice/control_response"
+    topic = "/audio_voice_control_response"
 
     class msg_class(NestedClass):
         def __init__(self):
@@ -1276,3 +1301,28 @@ class audio_voice_control_response(msg):
     def __init__(self):
         super().__init__()
         self.msg = self.msg_class()  # 消息体
+
+#模块管理
+class modules_manage_pub(msg):
+    """
+    定义一个应用消息,消息结构如下：
+    {
+        "msg":[
+            {
+                "name":"Joysticks", //模块名称
+                "status":true //模块状态,true:开启,false:关闭
+            }
+        ]
+    }
+    """
+    topic = "/audio/voice/control_response"
+
+    class data_class_module(NestedClass):
+        def __init__(self):
+            super().__init__()
+            self.name = ""  # int型
+            self.status = ""  # string型
+            
+    def __init__(self):
+        super().__init__()
+        self.msg = []  # 消息体
